@@ -76,13 +76,13 @@ mod ftx_linear_future {
         gen_test_code!(
             FtxWSClient,
             subscribe_trade,
-            &vec!["BTC-0325".to_string(), "BTC-0624".to_string()]
+            &vec!["BTC-0624".to_string(), "ETH-0624".to_string()]
         );
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn subscribe_bbo() {
-        gen_test_code!(FtxWSClient, subscribe_bbo, &vec!["BTC-0325".to_string()]);
+        gen_test_code!(FtxWSClient, subscribe_bbo, &vec!["BTC-0624".to_string()]);
     }
 
     #[tokio::test(flavor = "multi_thread")]
@@ -90,7 +90,7 @@ mod ftx_linear_future {
         gen_test_code!(
             FtxWSClient,
             subscribe_orderbook,
-            &vec!["BTC-0325".to_string()]
+            &vec!["BTC-0624".to_string()]
         );
     }
 }
@@ -105,7 +105,7 @@ mod ftx_move {
         gen_test_code!(
             FtxWSClient,
             subscribe_trade,
-            &vec!["BTC-MOVE-2022Q1".to_string()]
+            &vec!["BTC-MOVE-2022Q2".to_string()]
         );
     }
 
@@ -114,7 +114,7 @@ mod ftx_move {
         gen_test_code!(
             FtxWSClient,
             subscribe_bbo,
-            &vec!["BTC-MOVE-2022Q1".to_string()]
+            &vec!["BTC-MOVE-2022Q2".to_string()]
         );
     }
 
@@ -123,7 +123,7 @@ mod ftx_move {
         gen_test_code!(
             FtxWSClient,
             subscribe_orderbook,
-            &vec!["BTC-MOVE-2022Q1".to_string()]
+            &vec!["BTC-MOVE-2022Q2".to_string()]
         );
     }
 }
